![logo](https://raw.githubusercontent.com/cybergarage/uecho-py/main/doc/img/logo.png?token=AAEPHD4KEMD7MIIGJNOQPX3BR7O4M)

[![pytest](https://github.com/cybergarage/uecho-py/actions/workflows/pytest.yml/badge.svg)](https://github.com/cybergarage/uecho-py/actions/workflows/pytest.yml)
![](https://img.shields.io/badge/python-3.6-blue.svg)
![](https://img.shields.io/badge/python-3.7-blue.svg)
![](https://img.shields.io/badge/python-3.8-blue.svg)
![](https://img.shields.io/badge/python-3.9-blue.svg)
![](https://img.shields.io/badge/python-3.10-blue.svg)

The `uecho-py` is a portable and cross platform development framework for creating controller applications and devices of [ECHONET Lite][enet] for Python developers. [ECHONET][enet] is an open standard specification for IoT devices in Japan, it specifies more than 100 IoT devices such as crime prevention sensor, air conditioner and refrigerator.

The `uecho-py` is designed for easy development of [ECHONET Lite][enet] devices and controllers on Raspberry Pi and has been tested on Raspberry Pi OS too.

![](https://raw.githubusercontent.com/cybergarage/uecho-py/main/doc/img/monolight-sense.jpg)

## Installation

You can install `uecho-py` using `pip` as the following:

```
 $ pip install uecho
 ```

## Table of Contents

- Controller
  - [Overview of Controller](https://github.com/cybergarage/uecho-py/blob/master/doc/controller_overview.md)
- Device
  - [Overview of Device](https://github.com/cybergarage/uecho-py/blob/master/doc/device_overview.md)
  - [Inside of Device](https://github.com/cybergarage/uecho-py/blob/master/doc/device_inside.md)
- [Examples](https://github.com/cybergarage/uecho-py/blob/master/doc/examples.md)

## References

* [Documentation (docstring)](https://cybergarage.github.io/uecho-py/)

[enet]:http://echonet.jp/english/
